AmiDistributionConfiguration class

Define and configure the output AMIs of the pipeline.

Constructors

AmiDistributionConfiguration({Map<String, String>? amiTags, String? description, String? kmsKeyId, LaunchPermissionConfiguration? launchPermission, String? name, List<String>? targetAccountIds})
AmiDistributionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

amiTags → Map<String, String>?
The tags to apply to AMIs distributed to this Region.
final
description → String?
The description of the distribution configuration. Minimum and maximum length are in characters.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The KMS key identifier used to encrypt the distributed image.
final
launchPermission → LaunchPermissionConfiguration?
Launch permissions can be used to configure which AWS accounts can use the AMI to launch instances.
final
name → String?
The name of the distribution configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetAccountIds → List<String>?
The ID of an account to which you want to distribute an image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited