ComponentVersion class

A high-level overview of a component semantic version.

Constructors

ComponentVersion({String? arn, String? dateCreated, String? description, String? name, String? owner, Platform? platform, List<String>? supportedOsVersions, ComponentType? type, String? version})
ComponentVersion.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the component.
final
dateCreated → String?
The date that the component was created.
final
description → String?
The description of the component.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the component.
final
owner → String?
The owner of the component.
final
platform → Platform?
The platform of the component.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedOsVersions → List<String>?
The operating system (OS) version supported by the component. If the OS information is available, a prefix match is performed against the parent image OS version during image recipe creation.
final
type → ComponentType?
The type of the component denotes whether the component is used to build the image or only to test it.
final
version → String?
The semantic version of the component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited