Container class

A container encapsulates the runtime environment for an application.

Constructors

Container({List<String>? imageUris, String? region})
Container.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageUris → List<String>?
A list of URIs for containers created in the context Region.
final
region → String?
Containers and container images are Region-specific. This is the Region context for the container.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited