ContainerDistributionConfiguration class

Container distribution settings for encryption, licensing, and sharing in a specific Region.

Constructors

ContainerDistributionConfiguration({required TargetContainerRepository targetRepository, List<String>? containerTags, String? description})
ContainerDistributionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

containerTags → List<String>?
Tags that are attached to the container distribution configuration.
final
description → String?
The description of the container distribution configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetRepository → TargetContainerRepository
The destination repository for the container distribution configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited