ContainerRecipe class

A container recipe.

Constructors

ContainerRecipe({String? arn, List<ComponentConfiguration>? components, ContainerType? containerType, String? dateCreated, String? description, String? dockerfileTemplateData, bool? encrypted, String? kmsKeyId, String? name, String? owner, String? parentImage, Platform? platform, Map<String, String>? tags, TargetContainerRepository? targetRepository, String? version, String? workingDirectory})
ContainerRecipe.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the container recipe.
final
components → List<ComponentConfiguration>?
Components for build and test that are included in the container recipe.
final
containerType → ContainerType?
Specifies the type of container, such as Docker.
final
dateCreated → String?
The date when this container recipe was created.
final
description → String?
The description of the container recipe.
final
dockerfileTemplateData → String?
Dockerfiles are text documents that are used to build Docker containers, and ensure that they contain all of the elements required by the application running inside. The template data consists of contextual variables where Image Builder places build information or scripts, based on your container image recipe.
final
encrypted → bool?
A flag that indicates if the target container is encrypted.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
Identifies which KMS key is used to encrypt the container image for distribution to the target Region.
final
name → String?
The name of the container recipe.
final
owner → String?
The owner of the container recipe.
final
parentImage → String?
The source image for the container recipe.
final
platform → Platform?
The system platform for the container, such as Windows or Linux.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
Tags that are attached to the container recipe.
final
targetRepository → TargetContainerRepository?
The destination repository for the container image.
final
version → String?
The semantic version of the container recipe (<major>.<minor>.<patch>).
final
workingDirectory → String?
The working directory for use during build and test workflows.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited