ContainerRecipeSummary class

A summary of a container recipe

Constructors

ContainerRecipeSummary({String? arn, ContainerType? containerType, String? dateCreated, String? name, String? owner, String? parentImage, Platform? platform, Map<String, String>? tags})
ContainerRecipeSummary.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the container recipe.
final
containerType → ContainerType?
Specifies the type of container, such as "Docker".
final
dateCreated → String?
The date when this container recipe was created.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the container recipe.
final
owner → String?
The owner of the container recipe.
final
parentImage → String?
The source image for the container recipe.
final
platform → Platform?
The system platform for the container, such as Windows or Linux.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
Tags that are attached to the container recipe.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited