DeleteInfrastructureConfigurationResponse class

Constructors

DeleteInfrastructureConfigurationResponse({String? infrastructureConfigurationArn, String? requestId})
DeleteInfrastructureConfigurationResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
infrastructureConfigurationArn → String?
The Amazon Resource Name (ARN) of the infrastructure configuration that was deleted.
final
requestId → String?
The request ID that uniquely identifies this request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited