DistributionConfiguration class

A distribution configuration.

Constructors

DistributionConfiguration({required int timeoutMinutes, String? arn, String? dateCreated, String? dateUpdated, String? description, List<Distribution>? distributions, String? name, Map<String, String>? tags})
DistributionConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the distribution configuration.
final
dateCreated → String?
The date on which this distribution configuration was created.
final
dateUpdated → String?
The date on which this distribution configuration was last updated.
final
description → String?
The description of the distribution configuration.
final
distributions → List<Distribution>?
The distributions of the distribution configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the distribution configuration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
The tags of the distribution configuration.
final
timeoutMinutes → int
The maximum duration in minutes for this distribution configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited