EbsInstanceBlockDeviceSpecification class

Amazon EBS-specific block device mapping specifications.

Constructors

EbsInstanceBlockDeviceSpecification({bool? deleteOnTermination, bool? encrypted, int? iops, String? kmsKeyId, String? snapshotId, int? volumeSize, EbsVolumeType? volumeType})
EbsInstanceBlockDeviceSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

deleteOnTermination → bool?
Use to configure delete on termination of the associated device.
final
encrypted → bool?
Use to configure device encryption.
final
hashCode → int
The hash code for this object.
no setterinherited
iops → int?
Use to configure device IOPS.
final
kmsKeyId → String?
Use to configure the KMS key to use when encrypting the device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotId → String?
The snapshot that defines the device contents.
final
volumeSize → int?
Use to override the device's volume size.
final
volumeType → EbsVolumeType?
Use to override the device's volume type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited