GetContainerRecipeResponse class

Constructors

GetContainerRecipeResponse({ContainerRecipe? containerRecipe, String? requestId})
GetContainerRecipeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

containerRecipe → ContainerRecipe?
The container recipe object that is returned.
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → String?
The request ID that uniquely identifies this request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited