Image class

An image build version.

Constructors

Image({String? arn, ContainerRecipe? containerRecipe, String? dateCreated, DistributionConfiguration? distributionConfiguration, bool? enhancedImageMetadataEnabled, ImageRecipe? imageRecipe, ImageTestsConfiguration? imageTestsConfiguration, InfrastructureConfiguration? infrastructureConfiguration, String? name, String? osVersion, OutputResources? outputResources, Platform? platform, String? sourcePipelineArn, String? sourcePipelineName, ImageState? state, Map<String, String>? tags, ImageType? type, String? version})
Image.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the image.
final
containerRecipe → ContainerRecipe?
The container recipe used to create the container image type.
final
dateCreated → String?
The date on which this image was created.
final
distributionConfiguration → DistributionConfiguration?
The distribution configuration used when creating this image.
final
enhancedImageMetadataEnabled → bool?
Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default.
final
hashCode → int
The hash code for this object.
no setterinherited
imageRecipe → ImageRecipe?
The image recipe used when creating the image.
final
imageTestsConfiguration → ImageTestsConfiguration?
The image tests configuration used when creating this image.
final
infrastructureConfiguration → InfrastructureConfiguration?
The infrastructure used when creating this image.
final
name → String?
The name of the image.
final
osVersion → String?
The operating system version of the instance. For example, Amazon Linux 2, Ubuntu 18, or Microsoft Windows Server 2019.
final
outputResources → OutputResources?
The output resources produced when creating this image.
final
platform → Platform?
The platform of the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourcePipelineArn → String?
The Amazon Resource Name (ARN) of the image pipeline that created this image.
final
sourcePipelineName → String?
The name of the image pipeline that created this image.
final
state → ImageState?
The state of the image.
final
tags → Map<String, String>?
The tags of the image.
final
type → ImageType?
Specifies whether this is an AMI or container image.
final
version → String?
The semantic version of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited