ImageRecipe class

An image recipe.

Constructors

ImageRecipe({String? arn, List<InstanceBlockDeviceMapping>? blockDeviceMappings, List<ComponentConfiguration>? components, String? dateCreated, String? description, String? name, String? owner, String? parentImage, Platform? platform, Map<String, String>? tags, ImageType? type, String? version, String? workingDirectory})
ImageRecipe.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the image recipe.
final
blockDeviceMappings → List<InstanceBlockDeviceMapping>?
The block device mappings to apply when creating images from this recipe.
final
components → List<ComponentConfiguration>?
The components of the image recipe.
final
dateCreated → String?
The date on which this image recipe was created.
final
description → String?
The description of the image recipe.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the image recipe.
final
owner → String?
The owner of the image recipe.
final
parentImage → String?
The parent image of the image recipe.
final
platform → Platform?
The platform of the image recipe.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
The tags of the image recipe.
final
type → ImageType?
Specifies which type of image is created by the recipe - an AMI or a container image.
final
version → String?
The version of the image recipe.
final
workingDirectory → String?
The working directory to be used during build and test workflows.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited