ImageRecipeSummary class

A summary of an image recipe.

Constructors

ImageRecipeSummary({String? arn, String? dateCreated, String? name, String? owner, String? parentImage, Platform? platform, Map<String, String>? tags})
ImageRecipeSummary.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the image recipe.
final
dateCreated → String?
The date on which this image recipe was created.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the image recipe.
final
owner → String?
The owner of the image recipe.
final
parentImage → String?
The parent image of the image recipe.
final
platform → Platform?
The platform of the image recipe.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
The tags of the image recipe.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited