ImageState class

Image state shows the image status and the reason for that status.

Constructors

ImageState({String? reason, ImageStatus? status})
ImageState.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → String?
The reason for the image's status.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ImageStatus?
The status of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited