ImageSummary class

An image summary.

Constructors

ImageSummary({String? arn, String? dateCreated, String? name, String? osVersion, OutputResources? outputResources, String? owner, Platform? platform, ImageState? state, Map<String, String>? tags, ImageType? type, String? version})
ImageSummary.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the image.
final
dateCreated → String?
The date on which this image was created.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the image.
final
osVersion → String?
The operating system version of the instance. For example, Amazon Linux 2, Ubuntu 18, or Microsoft Windows Server 2019.
final
outputResources → OutputResources?
The output resources produced when creating this image.
final
owner → String?
The owner of the image.
final
platform → Platform?
The platform of the image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ImageState?
The state of the image.
final
tags → Map<String, String>?
The tags of the image.
final
type → ImageType?
Specifies whether this is an AMI or container image.
final
version → String?
The version of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited