ImageVersion class

An image semantic version.

Constructors

ImageVersion({String? arn, String? dateCreated, String? name, String? osVersion, String? owner, Platform? platform, ImageType? type, String? version})
ImageVersion.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the image semantic version.
final
dateCreated → String?
The date at which this image semantic version was created.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the image semantic version.
final
osVersion → String?
The operating system version of the instance. For example, Amazon Linux 2, Ubuntu 18, or Microsoft Windows Server 2019.
final
owner → String?
The owner of the image semantic version.
final
platform → Platform?
The platform of the image semantic version.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ImageType?
Specifies whether this is an AMI or container image.
final
version → String?
The semantic version of the image semantic version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited