InfrastructureConfiguration class

Details of the infrastructure configuration.

Constructors

InfrastructureConfiguration({String? arn, String? dateCreated, String? dateUpdated, String? description, String? instanceProfileName, List<String>? instanceTypes, String? keyPair, Logging? logging, String? name, Map<String, String>? resourceTags, List<String>? securityGroupIds, String? snsTopicArn, String? subnetId, Map<String, String>? tags, bool? terminateInstanceOnFailure})
InfrastructureConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the infrastructure configuration.
final
dateCreated → String?
The date on which the infrastructure configuration was created.
final
dateUpdated → String?
The date on which the infrastructure configuration was last updated.
final
description → String?
The description of the infrastructure configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceProfileName → String?
The instance profile of the infrastructure configuration.
final
instanceTypes → List<String>?
The instance types of the infrastructure configuration.
final
keyPair → String?
The EC2 key pair of the infrastructure configuration.
final
logging → Logging?
The logging configuration of the infrastructure configuration.
final
name → String?
The name of the infrastructure configuration.
final
resourceTags → Map<String, String>?
The tags attached to the resource created by Image Builder.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroupIds → List<String>?
The security group IDs of the infrastructure configuration.
final
snsTopicArn → String?
The SNS topic Amazon Resource Name (ARN) of the infrastructure configuration.
final
subnetId → String?
The subnet ID of the infrastructure configuration.
final
tags → Map<String, String>?
The tags of the infrastructure configuration.
final
terminateInstanceOnFailure → bool?
The terminate instance on failure configuration of the infrastructure configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited