InfrastructureConfigurationSummary class

The infrastructure used when building EC2 AMIs.

Constructors

InfrastructureConfigurationSummary({String? arn, String? dateCreated, String? dateUpdated, String? description, String? name, Map<String, String>? resourceTags, Map<String, String>? tags})
InfrastructureConfigurationSummary.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the infrastructure configuration.
final
dateCreated → String?
The date on which the infrastructure configuration was created.
final
dateUpdated → String?
The date on which the infrastructure configuration was last updated.
final
description → String?
The description of the infrastructure configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the infrastructure configuration.
final
resourceTags → Map<String, String>?
The tags attached to the image created by Image Builder.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → Map<String, String>?
The tags of the infrastructure configuration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited