InstanceBlockDeviceMapping class

Defines block device mappings for the instance used to configure your image.

Constructors

InstanceBlockDeviceMapping({String? deviceName, EbsInstanceBlockDeviceSpecification? ebs, String? noDevice, String? virtualName})
InstanceBlockDeviceMapping.fromJson(Map<String, dynamic> json)
factory

Properties

deviceName → String?
The device to which these mappings apply.
final
ebs → EbsInstanceBlockDeviceSpecification?
Use to manage Amazon EBS-specific configuration for this mapping.
final
hashCode → int
The hash code for this object.
no setterinherited
noDevice → String?
Use to remove a mapping from the parent image.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualName → String?
Use to manage instance ephemeral devices.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited