ListContainerRecipesResponse class

Constructors

ListContainerRecipesResponse({List<ContainerRecipeSummary>? containerRecipeSummaryList, String? nextToken, String? requestId})
ListContainerRecipesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

containerRecipeSummaryList → List<ContainerRecipeSummary>?
The list of container recipes returned for the request.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The next token field is used for paginated responses. When this is not empty, there are additional container recipes that the service has not included in this response. Use this token with the next request to retrieve additional list items.
final
requestId → String?
The request ID that uniquely identifies this request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited