PutContainerRecipePolicyResponse class

Constructors

PutContainerRecipePolicyResponse({String? containerRecipeArn, String? requestId})
PutContainerRecipePolicyResponse.fromJson(Map<String, dynamic> json)
factory

Properties

containerRecipeArn → String?
The Amazon Resource Name (ARN) of the container recipe that this policy was applied to.
final
hashCode → int
The hash code for this object.
no setterinherited
requestId → String?
The request ID that uniquely identifies this request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited