TargetContainerRepository class

The container repository where the output container image is stored.

Constructors

TargetContainerRepository({required String repositoryName, required ContainerRepositoryService service})
TargetContainerRepository.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
repositoryName → String
The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → ContainerRepositoryService
Specifies the service in which this image was registered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited